aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools
diff options
context:
space:
mode:
authorGravatar Ravi Mistry <rmistry@google.com>2017-09-11 11:00:34 -0400
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2017-09-11 15:28:05 +0000
commita2bdf005f3c706065d1aa93f319f4b73932721d4 (patch)
treece64223230053df7db85c94b848ad526e64269cd /tools
parent6a7a704aa4c4e1862f63f42b3e6df997d472dd2f (diff)
Add a "[DO NOT SUBMIT]" prefix to the uploaded Android change
Since the script cannot do anything to prevent submission via the API it might help to atleast add a "[DO NOT SUBMIT]" prefix. NoTry: true Bug: skia:7016 Change-Id: I825f28947df85a4d54ead764f8d363e12f83fbfb Reviewed-on: https://skia-review.googlesource.com/44840 Commit-Queue: Ravi Mistry <rmistry@google.com> Reviewed-by: Mike Klein <mtklein@google.com>
Diffstat (limited to 'tools')
-rw-r--r--tools/android/upload_to_android.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/tools/android/upload_to_android.py b/tools/android/upload_to_android.py
index 6580b72f73..01213db1e5 100644
--- a/tools/android/upload_to_android.py
+++ b/tools/android/upload_to_android.py
@@ -121,11 +121,12 @@ About to run repo init. If it hangs asking you to run glogin then please:
shell=True)
subprocess.check_call('git cherry-pick FETCH_HEAD', shell=True)
# Amend the commit message to add "Test:" which is required by Android
# presubmit checks.
original_commit_message = change_details['subject']
new_commit_message = (
- "%s\n\nTest: Presubmit checks will test this change." % (
+ '[DO NOT SUBMIT] %s\n\n'
+ 'Test: Presubmit checks will test this change.' % (
original_commit_message))
subprocess.check_call('git commit --amend -m "%s"' % new_commit_message,
shell=True)
@@ -121,11 +121,12 @@ About to run repo init. If it hangs asking you to run glogin then please:
shell=True)
subprocess.check_call('git cherry-pick FETCH_HEAD', shell=True)
- # Amend the commit message to add "Test:" which is required by Android
- # presubmit checks.
+ # Amend the commit message to add a "[DO NOT SUBMIT]" prefix and a "Test:"
+ # line which is required by Android presubmit checks.
original_commit_message = change_details['subject']
new_commit_message = (